@@ -10,6 +10,7 @@ mod method_signature;
 mod param_flags;
 mod row;
 mod signature;
+mod signature_kind;
 mod tables;
 mod traits;
 mod type_kind;
@@ -30,6 +31,7 @@ pub use method_signature::*;
 pub use param_flags::*;
 pub use row::*;
 pub use signature::*;
+pub use signature_kind::*;
 pub use tables::*;
 pub use traits::*;
 pub use type_kind::*;
