@@ -28,12 +28,16 @@ impl Param {
         self.flags().input()
     }
 
-    pub fn is_const(&self) -> bool {
-        self.has_attribute("ConstAttribute")
+    pub fn is_com_out_ptr(&self) -> bool {
+        self.has_attribute("ComOutPtrAttribute")
     }
 
     pub fn array_info(&self) -> bool {
         // TODO: replace bool return with actual array info from attribute
         self.has_attribute("NativeArrayInfoAttribute")
     }
+
+    pub fn has_alternate_success_code(&self) -> bool {
+        self.has_attribute("AlternateSuccessCodesAttribute")
+    }
 }
